@@ -1,5 +1,5 @@
 /* libmondo-devices.c                 Subroutines for handling devices
-   $Id: libmondo-devices.c 256 2005-12-22 10:59:02Z bcornec $
+   $Id: libmondo-devices.c 305 2006-01-12 16:37:42Z bcornec $
 .
 
 
@@ -251,7 +251,7 @@
 #endif
 
 /*@unused@*/
-//static char cvsid[] = "$Id: libmondo-devices.c 256 2005-12-22 10:59:02Z bcornec $";
+//static char cvsid[] = "$Id: libmondo-devices.c 305 2006-01-12 16:37:42Z bcornec $";
 
 extern int g_current_media_number;
 extern double g_kernel_version;
@@ -1436,7 +1436,7 @@ bool is_this_a_valid_disk_format(char *format)
 			"lsvfs | tr -s '\t' ' ' | grep -v Filesys | grep -v -- -- | cut -d' ' -f1 | tr -s '\n' ' '");
 #else
 	sprintf(command,
-			"cat /proc/filesystems | grep -v nodev | tr -s '\t' ' ' | cut -d' ' -f2 | tr -s '\n' ' '");
+			"grep -v nodev /proc/filesystems | tr -s '\t' ' ' | cut -d' ' -f2 | tr -s '\n' ' '");
 #endif
 
 	pin = popen(command, "r");
@@ -2433,7 +2433,7 @@ char *list_of_NFS_devices_and_mounts(void)
 		   ("mount -t coda,ncpfs,nfs,smbfs,cifs | tr -s '\t' ' ' | cut -d' ' -f3 | tr -s '\n' ' ' | awk '{print $0;}'"));
 	strcpy(exclude_these_devices,
 		   call_program_and_get_last_line_of_output
-		   ("cat /etc/fstab | tr -s '\t' ' ' | grep -E '( (coda|ncpfs|nfs|smbfs|cifs) )' | cut -d' ' -f1 | tr -s '\n' ' ' | awk '{print $0;}'"));
+		   ("tr -s '\t' ' ' < /etc/fstab | grep -E '( (coda|ncpfs|nfs|smbfs|cifs) )' | cut -d' ' -f1 | tr -s '\n' ' ' | awk '{print $0;}'"));
 	sprintf(result_sz, "%s %s", exclude_these_directories,
 			exclude_these_devices);
 	paranoid_free(exclude_these_devices);
@@ -2463,7 +2463,7 @@ char *list_of_NFS_mounts_only(void)
 		   ("mount -t coda,ncpfs,nfs,smbfs,cifs | tr -s '\t' ' ' | cut -d' ' -f3 | tr -s '\n' ' ' | awk '{print $0;}'"));
 	strcpy(exclude_these_devices,
 		   call_program_and_get_last_line_of_output
-		   ("cat /etc/fstab | tr -s '\t' ' ' | grep -E '( (coda|ncpfs|nfs|smbfs|cifs) )' | cut -d' ' -f1 | tr -s '\n' ' ' | awk '{print $0;}'"));
+		   ("tr -s '\t' ' ' < /etc/fstab | grep -E '( (coda|ncpfs|nfs|smbfs|cifs) )' | cut -d' ' -f1 | tr -s '\n' ' ' | awk '{print $0;}'"));
 	sprintf(result_sz, "%s", exclude_these_directories);
 	paranoid_free(exclude_these_devices);
 	paranoid_free(exclude_these_directories);
@@ -2522,11 +2522,11 @@ void sensibly_set_tmpdir_and_scratchdir(struct s_bkpinfo *bkpinfo)
 #ifdef __FreeBSD__
 	strcpy(tmp,
 		   call_program_and_get_last_line_of_output
-		   ("df -m -t nonfs,msdosfs,ntfs,smbfs,smb,cifs | tr -s '\t' ' ' | grep -v none | grep -v Filesystem | awk '{printf \"%s %s\\n\", $4, $6;}' | sort -n | tail -n1 | awk '{print $NF;}'"));
+		   ("df -m -P -t nonfs,msdosfs,ntfs,smbfs,smb,cifs | tr -s '\t' ' ' | grep -v none | grep -v Filesystem | awk '{printf \"%s %s\\n\", $4, $6;}' | sort -n | tail -n1 | awk '{print $NF;}'"));
 #else
 	strcpy(tmp,
 		   call_program_and_get_last_line_of_output
-		   ("df -m -x nfs -x vfat -x ntfs -x smbfs -x smb -x cifs | sed 's/                  /devdev/' | tr -s '\t' ' ' | grep -v none | grep -v Filesystem | grep -v /dev/shm | awk '{printf \"%s %s\\n\", $4, $6;}' | sort -n | tail -n1 | awk '{print $NF;}'"));
+		   ("df -m -P -x nfs -x vfat -x ntfs -x smbfs -x smb -x cifs | sed 's/                  /devdev/' | tr -s '\t' ' ' | grep -v none | grep -v Filesystem | grep -v /dev/shm | awk '{printf \"%s %s\\n\", $4, $6;}' | sort -n | tail -n1 | awk '{print $NF;}'"));
 #endif
 
 	if (tmp[0] != '/') {
