@@ -1,5 +1,5 @@
 /* my-stuff.h
-   $Id: my-stuff.h 237 2005-12-19 19:23:17Z bcornec $
+   $Id: my-stuff.h 576 2006-05-25 12:00:37Z bcornec $
 .
 
 
@@ -231,6 +231,11 @@ char *trace_log_ptr;
  */
 #define MONDO_CFG_FILE_STUB "tmp/mondo-restore.cfg"
 
+/**
+ * The RAID kernel proc file
+ */
+#define MDSTAT_FILE "/proc/mdstat"
+
 /**
  * @bug Apparently unused.
  */
@@ -276,7 +281,7 @@ extern void _mondo_assert_fail(const char *file, const char *function,
 #define BLK_START_BIGGIEFILES	30	///< Marker block: start the biggiefile section.
 #define BLK_STOP_BIGGIEFILES	39	///< Marker block: stop the biggiefile section.
 #define BLK_START_A_NORMBIGGIE	40	///< Marker block: start a normal biggiefile.
-#define BLK_START_A_PIHBIGGIE	41	///< Marker block: start a partimagehack'd biggiefile
+#define BLK_START_A_PIHBIGGIE	41	///< Marker block: start a ntfsprog'd biggiefile
 #define BLK_START_EXTENDED_ATTRIBUTES 45	///< Marker block: start xattr/acl info
 #define BLK_STOP_EXTENDED_ATTRIBUTES 46	///< Marker block: stop xattr/acl info
 #define BLK_START_EXAT_FILE     47
@@ -344,22 +349,22 @@ extern void _mondo_assert_fail(const char *file, const char *function,
 /**
  * @c growisofs command to generate a bootable DVD using isolinux, except for the directory to image.
  */
-#define MONDO_GROWISOFS_REGULAR_SYSLINUX "growisofs -speed=1 -use-the-force-luke -J -no-emul-boot -boot-load-size 4 -b isolinux.bin --boot-info-table -c boot.cat -boot-load-size 4 -r -p MondoRescue -publisher www.mondorescue.org -A Mondo_Rescue_GPL_Version -V _CD#_ -v"
+#define MONDO_GROWISOFS_REGULAR_SYSLINUX "growisofs -use-the-force-luke -J -no-emul-boot -boot-load-size 4 -b isolinux.bin --boot-info-table -c boot.cat -boot-load-size 4 -r -p MondoRescue -publisher www.mondorescue.org -A Mondo_Rescue_GPL_Version -V _CD#_ -v"
 
 /**
  * @c growisofs command to generate a bootable DVD using LILO, except for the directory to image.
 	 */// -b images/mindi-boot.2880.img
-#define MONDO_GROWISOFS_REGULAR_ELILO     "growisofs -speed=1 -use-the-force-luke -no-emul-boot -b images/mindi-boot.2880.img -c boot.cat -J -r -p MondoRescue -publisher www.mondorescue.org -A Mondo_Rescue_GPL -V _CD#_ -v"
+#define MONDO_GROWISOFS_REGULAR_ELILO     "growisofs -use-the-force-luke -no-emul-boot -b images/mindi-boot.2880.img -c boot.cat -J -r -p MondoRescue -publisher www.mondorescue.org -A Mondo_Rescue_GPL -V _CD#_ -v"
 
 /**
  * @c growisofs command to generate a bootable DVD using LILO, except for the directory to image.
 	 */// -b images/mindi-boot.2880.img
-#define MONDO_GROWISOFS_REGULAR_LILO     "growisofs -speed=1 -no-emul-boot -b isolinux.bin -c boot.cat -J -r -p MondoRescue -publisher www.mondorescue.org -A Mondo_Rescue_GPL -V _CD#_ -v"
+#define MONDO_GROWISOFS_REGULAR_LILO     "growisofs -no-emul-boot -b isolinux.bin -c boot.cat -J -r -p MondoRescue -publisher www.mondorescue.org -A Mondo_Rescue_GPL -V _CD#_ -v"
 
 /**
  * @c growisofs command to generate a nonbootable DVD, except for the directory to image.
  */
-#define MONDO_GROWISOFS_NONBOOT          "growisofs -speed=1 -use-the-force-luke -J -r -p MondoRescue -publisher www.mondorescue.org -A Mondo_Rescue_GPL -V _CD#_ -v"
+#define MONDO_GROWISOFS_NONBOOT          "growisofs -use-the-force-luke -J -r -p MondoRescue -publisher www.mondorescue.org -A Mondo_Rescue_GPL -V _CD#_ -v"
 
 /**
  * Welcome string displayed at the top of the newt interface.
@@ -442,7 +447,7 @@ extern void _mondo_assert_fail(const char *file, const char *function,
 /**
  * Malloc @p x to be MAX_STR_LEN bytes and call fatal_error() if we're out of memory.
  */
-#define malloc_string(x) { x = malloc(MAX_STR_LEN); if (!x) { fatal_error("Unable to malloc"); } x[0] = x[1] = '\0'; }
+#define malloc_string(x) { x = (char *)malloc(MAX_STR_LEN); if (!x) { fatal_error("Unable to malloc"); } x[0] = x[1] = '\0'; }
 
 /**
  * Path to the location the hard drive is mounted on during a restore.
@@ -517,13 +522,12 @@ extern void _mondo_assert_fail(const char *file, const char *function,
 
 #define DEFAULT_DEBUG_LEVEL 4	///< By default, don't log messages with a loglevel higher than this.
 
-#define SZ_PARTIMAGE_VOLSIZE "1048576"	// was 4096
-#define PARTIMAGE_PARAMS "-z0 -V" SZ_PARTIMAGE_VOLSIZE " -o -b -d -g1"
+#define SZ_NTFSPROG_VOLSIZE "1048576"	// was 4096
+#define NTFSPROG_PARAMS "-z0 -V" SZ_NTFSPROG_VOLSIZE " -o -b -d -g1"
 
 #define MNT_CDROM "/mnt/cdrom"
 #define MNT_FLOPPY "/mnt/floppy"
 
-#define FREELOADER				// You're not a paying customer
 #define DEFAULT_MR_LOGLEVEL 4
 
 #endif							/* _MY_STUFF_H_ */
