@@ -1,5 +1,5 @@
 /* newt-specific.c
-   $Id: newt-specific.c 213 2005-12-15 00:41:46Z bcornec $
+   $Id: newt-specific.c 586 2006-05-29 09:36:33Z bcornec $
 
   subroutines which do display-type things
   and use the newt library to do them
@@ -121,7 +121,7 @@ extern "C" {
 #include "lib-common-externs.h"
 
 /*@unused@*/
-//static char cvsid[] = "$Id: newt-specific.c 213 2005-12-15 00:41:46Z bcornec $";
+//static char cvsid[] = "$Id: newt-specific.c 586 2006-05-29 09:36:33Z bcornec $";
 
 	extern pid_t g_mastermind_pid;
 	extern char *g_tmpfs_mountpt;
@@ -393,7 +393,7 @@ extern "C" {
 		paranoid_system("killall mindi 2> /dev/null");
 		kill_anything_like_this("/mondo/do-not");
 		kill_anything_like_this("tmp.mondo");
-		kill_anything_like_this("partimagehack");
+		kill_anything_like_this("ntfsclone");
 		sync();
 		sprintf(tmp, "umount %s", g_tmpfs_mountpt);
 		chdir("/");
@@ -423,7 +423,7 @@ extern "C" {
 
 		printf("---FATALERROR--- %s\n", error_string);
 		system
-			("cat /var/log/mondo-archive.log | gzip -9 > /tmp/MA.log.gz 2> /dev/null");
+			("gzip -9c /var/log/mondo-archive.log > /tmp/MA.log.gz 2> /dev/null");
 		printf
 				("If you require technical support, please contact the mailing list.\n");
 		printf("See http://www.mondorescue.org for details.\n");
@@ -996,7 +996,7 @@ extern "C" {
 			newtInit();
 			newtCls();
 			newtPushHelpLine
-				("Welcome to Mondo Rescue, by Hugo Rabson and the Internet. All rights reversed.");
+				("Welcome to Mondo Rescue, by Dev Team and the Internet. All rights reversed.");
 			/*  newtDrawRootText(28,0,"Welcome to Mondo Rescue"); */
 			newtDrawRootText(18, 0, WELCOME_STRING);
 			newtRefresh();
