@@ -7,7 +7,7 @@ copyright : (C) 2002 Mondo  Hugo Rabson
 email	  : Hugo Rabson <hugorabson@msn.com>
 edited by : by Stan Benoit 4/2002
 email     : troff@nakedsoul.org
-cvsid     : $Id: mondo-rstr-newt.c 128 2005-11-19 01:27:41Z bcornec $
+cvsid     : $Id: mondo-rstr-newt.c 273 2006-01-03 15:09:12Z bcornec $
 ***************************************************************************/
 
 /***************************************************************************
@@ -91,7 +91,7 @@ cvsid     : $Id: mondo-rstr-newt.c 128 2005-11-19 01:27:41Z bcornec $
 
 #include "mondo-rstr-newt.h"
 
-//static char cvsid[] = "$Id: mondo-rstr-newt.c 128 2005-11-19 01:27:41Z bcornec $";
+//static char cvsid[] = "$Id: mondo-rstr-newt.c 273 2006-01-03 15:09:12Z bcornec $";
 
 extern char err_log_lines[NOOF_ERR_LINES][MAX_STR_LEN];
 
@@ -604,7 +604,7 @@ choose_raid_level(struct OSSWAP (raid_device_record, vinum_plex) * raidrec)
 
 	assert(raidrec != NULL);
 	system
-		("cat /proc/mdstat | grep Pers > /tmp/raid-personalities.txt 2> /dev/null");
+		("grep Pers /proc/mdstat > /tmp/raid-personalities.txt 2> /dev/null");
 	strcpy(personalities,
 		   last_line_of_file("/tmp/raid-personalities.txt"));
 	sprintf(prompt, "Please enter the RAID level you want. %s",
